@@ -18,7 +18,7 @@
 """
 usage: cb-image -h | --help
        cb-image --description=<image_description_path> --target-dir=<target_path> --bundle-id=<ID> --request-id=<UUID>
-           [(--repo-server=<name> --repo-path=<path> --ssh-user=<user> --ssh-pkey=<ssh_pkey_file>)]
+           [(--repo-server=<name> --repo-path=<path> --repo-arch=<name> --ssh-user=<user> --ssh-pkey=<ssh_pkey_file>)]
            [--local]
            [--profile=<name>...]
            [-- <kiwi_custom_build_command_args>...]
@@ -42,6 +42,10 @@ options:
     --repo-path=<path>
         Path to place build results on the repo server
 
+    --repo-arch=<name>
+        Architecture name as used in the cloud_builder
+        metadata file to describe the image target
+
     --repo-server=<name>
         Name or IP of collector repo server
 
@@ -70,6 +74,9 @@ from docopt import docopt
 from tempfile import TemporaryDirectory
 from kiwi.command import Command
 from kiwi.path import Path
+from typing import (
+    List, Dict
+)
 
 from cloud_builder.version import __version__
 from cloud_builder.cloud_logger import CBCloudLogger
@@ -226,18 +233,25 @@ def main() -> None:
         Path.wipe(package_build_target_dir)
         Path.create(package_build_target_dir)
 
+        binary_map: Dict[str, List[str]] = {}
         for package in glob.iglob(f'{target_dir}/*'):
             repo_meta = CBRepository(package).get_repo_meta(
                 base_repo_path=package_build_target_dir
             )
+            repo_file_basename = os.path.basename(repo_meta.repo_file)
+            package_indicator_name = '.package_{0}.{1}'.format(
+                args['--repo-arch'], os.path.basename(image_name)
+            )
+            if package_indicator_name not in binary_map:
+                binary_map[package_indicator_name] = []
+            binary_map[package_indicator_name].append(repo_file_basename)
+
             os.rename(package, repo_meta.repo_file)
 
         Path.wipe(target_dir)
-        os.rename(
-            package_build_binary_dir, target_dir
-        )
+
         # Create packages list
-        for root, dirs, files in os.walk(target_dir):
+        for root, dirs, files in os.walk(package_build_binary_dir):
             for entry in files:
                 packages.append(os.path.join(root, entry))
         log.info(format(packages))
@@ -245,37 +259,52 @@ def main() -> None:
         # Sync target_binary_dir to repo server
         if args['--repo-server']:
             update_repo_indicator = os.path.join(
-                target_dir,
+                package_build_binary_dir,
                 args['--repo-path'], '.updaterepo'
             )
-            package_indicator = os.path.join(
-                target_dir,
-                args['--repo-path'], '.package.{image_name}'
-            )
-            # write a package indicator to tell the collector
-            # which binaries belongs to the package
-            with open(package_indicator, 'w') as package_binaries:
-                package_binaries.write(
-                    yaml.dump(packages, default_flow_style=False)
+            sync_command = [
+                'rsync', '-av', '-e', 'ssh -i {0} -o {1}'.format(
+                    args['--ssh-pkey'],
+                    'StrictHostKeyChecking=accept-new'
+                ), f'{package_build_binary_dir}/', '{0}@{1}:{2}'.format(
+                    args['--ssh-user'], args['--repo-server'],
+                    Defaults.get_repo_root()
                 )
-            # Write an update repo indicator to tell the collector
-            # to rebuild the repo metadata. The file also serves
-            # as indicator for the repo type
-            with open(update_repo_indicator, 'w') as flag:
-                flag.write(repo_meta.repo_type)
-            sync_call = Command.run(
-                [
-                    'rsync', '-av', '-e', 'ssh -i {0} -o {1}'.format(
-                        args['--ssh-pkey'],
-                        'StrictHostKeyChecking=accept-new'
-                    ), f'{target_dir}/', '{0}@{1}:{2}'.format(
-                        args['--ssh-user'], args['--repo-server'],
-                        Defaults.get_repo_root()
-                    )
-                ], raise_on_error=False
-            )
+            ]
+            # Sync new packages first
+            sync_call = Command.run(sync_command, raise_on_error=False)
             if sync_call.output:
                 log.info(sync_call.output)
+            if sync_call.returncode == 0:
+                # write package indicator files to tell the collector
+                # which binaries belongs to the package
+                for package_indicator_name in binary_map.keys():
+                    package_indicator = os.path.join(
+                        package_build_binary_dir, args['--repo-path'],
+                        package_indicator_name
+                    )
+                    binaries_for_arch = []
+                    for package in packages:
+                        if os.path.basename(package) in binary_map[
+                            package_indicator_name
+                        ]:
+                            binaries_for_arch.append(package)
+                    with open(package_indicator, 'w') as package_binaries:
+                        package_binaries.write(
+                            yaml.dump(
+                                binaries_for_arch, default_flow_style=False
+                            )
+                        )
+                # Write an update repo indicator to tell the collector
+                # to rebuild the repo metadata. The file also serves
+                # as indicator for the repo type
+                with open(update_repo_indicator, 'w') as flag:
+                    flag.write(repo_meta.repo_type)
+                # Sync status indicators next
+                sync_call = Command.run(sync_command, raise_on_error=False)
+                if sync_call.output:
+                    log.info(sync_call.output)
+
             if sync_call.returncode != 0:
                 exit_code = 1
                 status = status_flags.package_binaries_sync_failed
